==> Lenpy-0.1.tar.gz: Lenpy-0.1/README.md <==

# Len'Py

Simplifies certain tasks when creating a game with Pygame

 - [GitHub](https://github.com/QuetzalcoutlDev/Lenpy)

![](https://github.com/QuetzalcoutlDev/Lenpy/main/art/logo.png?raw=true)

Len'Py is a module for the Python programming language that allows you to simplify certain tasks when creating a game with Pygame.
It also contains some useful tools for you to create a good game with Pygame.

# Characteristic

- Compatibility with XML Sprites made in Adobe Flash CS6 onwards
-Data Manager
- Some small tools (4 digit count, define animation of multiple images, create a directory with only one line of code)
- Draw a text on the screen in a slightly easier way
- TextButtons

Perhaps Len'Py is not as complete a module as Pygame_gui, but it will help you, as it is updated it will have more features and improve the ones it already has, and you can even propose or add your own.
But keep in mind that Len'Py is the only module with XML Sprites support (As far as I know)
Although I must say that the most powerful features that Len'Py has are the XML Sprites and the Data Manager.

## Requirements

 -Python 3.7+
 -Pygame 2.0.1+

## How to install

You can also install Len'Py by downloading the source code and running the following command in the console:

```
python setup.py install
```

In some Linux distributions (and I think in the current ones) to install it, this command is enough:

```
python3 setup.py install
```

If you already have Pygame installed, during the installation it should not throw any error, if so, remember to report it.

# How to use Len'Py?

Currently I haven't written a documentation, because I'm a bit new compared to other developers and also I don't have the internet to investigate, maybe the only way that will guide you for now to learn how to use Len'Py are the “examples” or looking at the source code itself and reviewing how the Len'Py code works.

# On what systems can I use Len'Py?

Len'Py is mostly only compatible with Microsoft Windows for now (Due to the points I explain below), but I can say that all features except Data Manager are compatible with Linux and Mac.

# Why Len'Py?

Len'Py is an abbreviation for Length-Pygame, which can stand for the length of work making a game with Pygame can be.
Len'Py I did it to share something to the Pygame community, so that people trust it more, and because I'm doing a project with Pygame and I don't want the XML sprites feature to be only mine or the project's but were everyone.

# Back me up

I'm not programming Len'Py to get something out of it, in fact it's just to learn, but you don't know how difficult it is to do something like this on a PC with only 2GB of RAM and a very old processor, not to mention 256MB of graphic memory, I don't mind doing it like this but with a few words of motivation it will suffice. :’)

If you want you can buy me a coffee or follow me on the networks that I leave below
Kofi: https://www.ko-fi.com/quetzalcoutl

# follow me

Twitter: https://twitter.com/ElQuetzalcoutl
Instagram: https://www.instagram.com/quetzalcoutldev/
My other networks: https://allmylinks.com/elquetzalcoutl

# My other projects

1. Lonely Imagination (DDLC inspired VN) :https://quetzalcoutl.itch.io/Alone
2.FNF mods: https://gamebanana.com/members/2176391
3. LMMS projects: https://lmms.io/lsp/?action=browse&user=QuetzalcoultDev

==> Lenpy-0.1.1.tar.gz: Lenpy-0.1.1/README.md <==

# Len'Py

Simplifies certain tasks when creating a game with Pygame

 - [GitHub](https://github.com/QuetzalcoutlDev/Lenpy)

![](https://github.com/QuetzalcoutlDev/Lenpy/blob/main/art/logo.png?raw=true)

Len'Py is a module for the Python programming language that allows you to simplify certain tasks when creating a game with Pygame.
It also contains some useful tools for you to create a good game with Pygame.

# Characteristics

- Compatibility with XML Sprites(Spritesheets) made in Adobe Flash CS6 onwards
- Data Manager
- Some small tools (4 digit count, define animation of multiple images, create a directory with only one line of code)
- Draw a text on the screen in a slightly easier way
- TextButtons, ImageButtons
- FPS Counter tool

Perhaps Len'Py is not as complete a module as Pygame_gui, but it will help you, as it is updated it will have more features and improve the ones it already has, and you can even propose or add your own.
But keep in mind that Len'Py is the only module with XML Sprites support (As far as I know)
Although I must say that the most powerful features that Len'Py has are the XML Sprites and the Data Manager.

## Requirements

- Python 3.7+
- Pygame 2.0.1+

## How to install


Run this command in a command prompt:

```
pip install lenpy
```

You can also install Len'Py by downloading the source code and running the following command in the console:

```
python setup.py install
```

In some Linux distributions (and I think in the current ones) to install it, this command is enough:

```
python3 setup.py install
```

If you already have Pygame installed, during the installation it should not throw any error, if so, remember to report it.

# How to use Len'Py?

Currently I haven't written a documentation, because I'm a bit new compared to other developers and also I don't have the internet to investigate, maybe the only way that will guide you for now to learn how to use Len'Py are the “examples” or looking at the source code itself and reviewing how the Len'Py code works.

# On what systems can I use Len'Py?

Len'Py is mostly only compatible with Microsoft Windows for now (Due to the points I explain below), but I can say that all features except Data Manager are compatible with Linux and Mac.

# Why Len'Py?

Len'Py is an abbreviation for Length-Pygame, which can stand for the length of work making a game with Pygame can be.
Len'Py I did it to share something to the Pygame community, so that people trust it more, and because I'm doing a project with Pygame and I don't want the XML sprites feature to be only mine or the project's but were everyone.

# Back me up

I'm not programming Len'Py to get something out of it, in fact it's just to learn, but you don't know how difficult it is to do something like this on a PC with only 2GB of RAM and a very old processor, not to mention 256MB of graphic memory, I don't mind doing it like this but with a few words of motivation it will suffice. :’)

If you want you can buy me a coffee or follow me on the networks that I leave below
Kofi: https://www.ko-fi.com/quetzalcoutl

# follow me

Twitter: https://twitter.com/ElQuetzalcoutl
Instagram: https://www.instagram.com/quetzalcoutldev/
My other networks: https://allmylinks.com/elquetzalcoutl

# My other projects

1. Lonely Imagination (DDLC inspired VN) :https://quetzalcoutl.itch.io/Alone
2. FNF mods: https://gamebanana.com/members/2176391
3. LMMS projects: https://lmms.io/lsp/?action=browse&user=QuetzalcoultDev
